// ============================================================================
// Project:	Deductive Database
// Filename:	argtype.cpp
// Purpose:	Argument types for predicates (int, atom, string)
// Last Change:	16.11.2015
// Language:	C++
// EMail:	brass@informatik.uni-halle.de
// WWW:		http://www.informatik.uni-halle.de/~brass/
// Address:	Feldschloesschen 15, D-06120 Halle (Saale), GERMANY
// Copyright:	(c) 1998-2015 by Stefan Brass
// License:	See file "LICENSE" for copying conditions.
// Note:	There is no warranty at all - this code may contain bugs.
// ============================================================================


//=============================================================================
// Interface:
//=============================================================================

#include "ver.h"
#include "check.h"
#include "argtype.h"

//=============================================================================
// Exported Functions:
//=============================================================================

//-----------------------------------------------------------------------------
// argtype_valid: Is the parameter a valid element of the enumeration type?
//-----------------------------------------------------------------------------

#ifdef	VER_DEBUG

bool	argtype_valid(argtype_t argtype)
{
	return( argtype == ARGTYPE_NULL ||
		argtype == ARGTYPE_INT ||
		argtype == ARGTYPE_ATOM ||
		argtype == ARGTYPE_STR ||
		argtype == ARGTYPE_ATOM_STR
	);
}

#endif


//-----------------------------------------------------------------------------
// argtype_name: String representation of this argument type.
//-----------------------------------------------------------------------------

str_t	argtype_name(argtype_t argtype)
{
	str_t name;
	
	switch(argtype) {
		case ARGTYPE_NULL:
			name = "NULL";
			break;
		case ARGTYPE_INT:
			name = "int";
			break;
		case ARGTYPE_ATOM:
			name = "atom";
			break;
		case ARGTYPE_STR:
			name = "string";
			break;
		case ARGTYPE_ATOM_STR:
			name = "atom or string";
			break;
		default:
			CHECK_IMPOSSIBLE(
				"argtype_name: unknown argument type");
			name = "? (unknown/illegal)";
			break;
	}
	
	return name;
}

